Description Usage Arguments Value See Also
Processes Proba-V data for subsequentent use in time-series analysis. Performs Proba-V cleaning and operations with parallel support using foreach
1 2 3 |
x |
Character. Directory where the data is located. Or list of file names. |
pattern |
Character. Only useful if x is of length 1. See list.files for more details |
tiles |
Character. Tiles to process, format "X10Y06", |
start_d |
Date. Starting date. |
QC_val |
Numeric. See |
fill |
Numeric. See |
as.is |
Logical. See |
outdir |
Character. Directory where the output should be written. |
ncores |
Numeric. Number of cores to use for processing. See registerDoParallel |
overwritw |
Logical. Wether to overwrite existing files using the same naming convention in outdir. ault is |
This function is used for its side effect of producing cleaned data, hence written to disk at outdir location
cleanProbaV, and timeStackProbaV for stacking.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.